@@ -16,7 +16,6 @@
 # under the License.
 from __future__ import annotations
 
-import logging
 from collections import defaultdict
 from contextlib import closing
 from enum import IntEnum
@@ -34,9 +33,6 @@ if TYPE_CHECKING:
     from airflow.hooks.base import BaseHook
 
 
-logger = logging.getLogger(__name__)
-
-
 class ColumnIndex(IntEnum):
     """Enumerates the indices of columns in information schema view."""
 
